pub struct CachedParseOutput {
pub interner: InternerSnapshot,
pub ast: Ast,
}Expand description
Envelope around a parsed file’s AST + interner snapshot, ready for bincode serialization to the parse cache.
Fields
interner: InternerSnapshotast: AstImplementations
Sourceimpl CachedParseOutput
impl CachedParseOutput
Sourcepub fn encode(&self) -> Result<Vec<u8>, EncodeError>
pub fn encode(&self) -> Result<Vec<u8>, EncodeError>
Serialize to the bincode wire format used by CacheStore::put.
Sourcepub fn decode(bytes: &[u8]) -> Result<Self, DecodeError>
pub fn decode(bytes: &[u8]) -> Result<Self, DecodeError>
Deserialize from the bincode wire format. Pairs with
CachedParseOutput::encode.