pub fn compute_sig_fp(ast: &Ast, interner: &ThreadedRodeo) -> CacheKeyExpand description
Compute sig_fp for a single file’s AST.
interner resolves the Spurs in ast to their string content so
the hash is stable across different Spur numberings (e.g. after
re-interning into a different build’s interner).